<?php
/**
 * Plugin Name: Consent Management Platform
 * Plugin URI: https://www.sharethis.com/gdpr-compliance-tool/
 * Description: Integrates the GDPR Compliance Tool directly into your website.
 * Version: 2.1.3
 * Author: ShareThis
 * Author URI: https://sharethis.com/
 * Text Domain: gdpr-compliance-tool
 * Domain Path: /languages
 * License:     GPL v2 or later

Copyright 2020 ShareThis

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

 * @package GDPRComplianceTool
 */

if ( version_compare( phpversion(), '5.3', '>=' ) ) {
	require_once __DIR__ . '/instance.php';
} else {
	if ( defined( 'WP_CLI' ) ) {
		WP_CLI::warning( gdpr_compliance_tool_php_version_text() );
	} else {
		add_action( 'admin_notices', 'gdpr_compliance_tool_php_version_error' );
	}
}

/**
 * Admin notice for incompatible versions of PHP.
 */
function gdpr_compliance_tool_php_version_error() {
	printf( '<div class="error"><p>%s</p></div>', esc_html( gdpr_compliance_tool_php_version_text() ) );
}

/**
 * String describing the minimum PHP version.
 *
 * @return string
 */
function gdpr_compliance_tool_php_version_text() {
	return __( 'Consent Management Platform plugin error: Your version of PHP is too old to run this plugin. You must be running PHP 5.3 or higher.', 'gdpr-compliance-tool' );
}

/**
 * Add a link to the settings page.
 *
 * @param string $links The links shown in the plugin page.
 *
 * @return array
 */
function _gdpr_compliance_tool_add_action_links( $links ) {
	$mylinks = array(
		'<a href="' . admin_url( 'admin.php?page=gdpr-compliance-tool' ) . '">Settings</a>',
	);
	return array_merge( $links, $mylinks );
}
