<?php
/**
 * Bootstraps the GDPR Compliance Tool plugin.
 *
 * @package GDPRComplianceTool
 */

namespace GDPRComplianceTool;

/**
 * Main plugin bootstrap file.
 */
class Plugin extends Plugin_Base
{

    /**
     * Plugin assets prefix.
     *
     * @var string Lowercased dashed prefix.
     */
    public $assets_prefix;

    /**
     * Plugin meta prefix.
     *
     * @var string Lowercased underscored prefix.
     */
    public $meta_prefix;

    /**
     * Plugin constructor.
     */
    public function __construct()
    {
        parent::__construct();

        // Initiate classes.
        $classes = array(
            new GDPRCompliance($this),
        );

        // Add classes doc hooks.
        foreach ($classes as $instance) {
            $this->add_doc_hooks($instance);
        }

        // Define some prefixes to use throughout the plugin.
        $this->assets_prefix = strtolower(preg_replace('/\B([A-Z])/', '-$1', __NAMESPACE__));
        $this->meta_prefix   = strtolower(preg_replace('/\B([A-Z])/', '_$1', __NAMESPACE__));
    }

    /**
     * Register MU Script
     *
     * @action wp_enqueue_scripts
     */
    public function registerAssets()
    {
        $propertyid = get_option('sharethis_property_id');
        $propertyid = ! empty($propertyid) ? explode('-', $propertyid, 2) : array();

        $sb_active = in_array(
            'sharethis-share-buttons/sharethis-share-buttons.php',
            apply_filters('active_plugins', get_option('active_plugins')),
            true
        );

        if (! $sb_active && is_array($propertyid) && array() !== $propertyid) {
            wp_register_script(
                "{$this->assets_prefix}-mu",
                "//platform-api.sharethis.com/js/sharethis.js#property={$propertyid[0]}&product=gdpr-compliance-tool-v2",
                [],
                '1.0.0',
                true
            );
        }
    }
}
